package knightminer.tcomplement.library.tanks;

import java.lang.ref.WeakReference;

import net.minecraftforge.fluids.FluidStack;
import net.minecraftforge.fluids.capability.FluidTankProperties;
import net.minecraftforge.fluids.capability.IFluidHandler;
import net.minecraftforge.fluids.capability.IFluidTankProperties;
import net.minecraftforge.fluids.capability.templates.EmptyFluidHandler;
import net.minecraftforge.fluids.capability.templates.FluidHandlerConcatenate;

public class FluidHandlerDrainOnlyWrapper extends FluidHandlerConcatenate {

	// we hold a weak reference as we don't want the drains when storing the wrapper to keep old tanks
	private final WeakReference<IFluidHandler> parent;

	public FluidHandlerDrainOnlyWrapper(IFluidHandler parent) {
		super(parent);
		this.parent = new WeakReference<>(parent);
	}

	// checks if the parent is no longer available, for example the smeltery containing the tank was removed
	public boolean hasParent() {
		return parent.get() != null;
	}

	@Override
	public IFluidTankProperties[] getTankProperties() {
		if(hasParent()) {
			IFluidHandler iFluidHandler = parent.get();
			assert iFluidHandler != null;
			IFluidTankProperties[] iFluidTankPropertiesArray = iFluidHandler.getTankProperties();
			if(iFluidTankPropertiesArray.length > 0) {
				IFluidTankProperties fluidTankProperties = iFluidHandler.getTankProperties()[0];
				return new IFluidTankProperties[]{new FluidTankProperties(fluidTankProperties.getContents(), fluidTankProperties.getCapacity(), false, true)};
			}
		}
		return EmptyFluidHandler.EMPTY_TANK_PROPERTIES_ARRAY;
	}

	@Override
	public int fill(FluidStack resource, boolean doFill) {
		return 0;
	}
}